=== modified file 'NEWS'
--- NEWS	2007-06-01 05:43:11 +0000
+++ NEWS	2007-06-01 22:16:55 +0000
@@ -39,6 +39,9 @@
       into account.
       (Vincent Ladeuil, #112719)
 
+    * WorkingTree4.get_file_sha1 no longer raises an exception when invoked
+      on a missing file.  (Aaron Bentley, #118186)
+
 bzr 0.16  2007-05-07
   
   BUGFIXES:

=== modified file 'bzrlib/tests/workingtree_implementations/test_workingtree.py'
--- bzrlib/tests/workingtree_implementations/test_workingtree.py	2007-03-23 01:41:37 +0000
+++ bzrlib/tests/workingtree_implementations/test_workingtree.py	2007-06-01 13:42:02 +0000
@@ -825,3 +825,14 @@
             actual_kind = tree.kind(names[i-1] + '-id')
             expected_kind = names[i]
             self.assertEqual(expected_kind, actual_kind)
+
+    def test_missing_file_sha1(self):
+        """If a file is missing, its sha1 should be reported as None."""
+        tree = self.make_branch_and_tree('.')
+        tree.lock_write()
+        self.addCleanup(tree.unlock)
+        self.build_tree(['file'])
+        tree.add('file', 'file-id')
+        tree.commit('file added')
+        os.unlink('file')
+        self.assertIs(None, tree.get_file_sha1('file-id'))

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2007-05-17 18:23:06 +0000
+++ bzrlib/workingtree_4.py	2007-06-01 13:42:02 +0000
@@ -414,7 +414,13 @@
         file_abspath = self.abspath(path)
         state = self.current_dirstate()
         if stat_value is None:
-            stat_value = os.lstat(file_abspath)
+            try:
+                stat_value = os.lstat(file_abspath)
+            except OSError, e:
+                if e.errno == errno.ENOENT:
+                    return None
+                else:
+                    raise
         link_or_sha1 = state.update_entry(entry, file_abspath,
                                           stat_value=stat_value)
         if entry[1][0][0] == 'f':

